@@ -1,6 +1,6 @@
-from enum import Enum
+from enum import IntEnum
 
-class DifficultyLevel(Enum):
+class DifficultyLevel(IntEnum):
     '''Difficulty levels for SQL assignments.'''
     
     EASY = 1
@@ -10,4 +10,5 @@ class DifficultyLevel(Enum):
     '''Moderate cognitive load, the assignments contains some elements not related to triggering the error'''
 
     HARD = 3
-    '''High cognitive load, the assignments contains elements not related to triggering the error and may require complex reasoning'''
\ No newline at end of file
+    '''High cognitive load, the assignments contains elements not related to triggering the error and may require complex reasoning'''
+
